@@ -2,6 +2,9 @@ library(testthat)
  Sys.setenv('OMP_THREAD_LIMIT'=2)
  library(rlibkriging)
 
+##library(rlibkriging, lib.loc="bindings/R/Rlibs")
+##library(testthat)
+
 for (kernel in c("gauss","exp","matern3_2","matern5_2")) {
   context(paste0("Check predict 1D for kernel ",kernel))
 
@@ -10,7 +13,6 @@ for (kernel in c("gauss","exp","matern3_2","matern5_2")) {
 #rlibkriging:::optim_log(3)
 #kernel="exp"
 
-
   f = function(x) 1-1/2*(sin(12*x)/(1+x)+2*cos(7*x)*x^5+0.7)
   #plot(f)
   n <- 5
@@ -25,8 +27,8 @@ for (kernel in c("gauss","exp","matern3_2","matern5_2")) {
                theta=matrix(k@covariance@range.val),has_theta=TRUE, is_theta_estim=FALSE))
   # m = as.list(r)
   
-  ntest <- 100
-  Xtest <- as.matrix(runif(ntest))
+  ntest <- 10
+  Xtest <- as.matrix(c(X,runif(ntest)))
   ptest <- DiceKriging::predict(k,Xtest,type="UK",cov.compute = TRUE,checkNames=F)
   Yktest <- ptest$mean
   sktest <- ptest$sd
@@ -50,7 +52,7 @@ for (kernel in c("gauss","exp","matern3_2","matern5_2")) {
   
   plot(f)
   points(X,y)
-  x=seq(0,1,,101)
+  x=seq(0,1,,5)
   lines(x,predict(k,x,type="UK",checkNames=F)$mean,lty=2,col='blue')
   polygon(
       c(x,rev(x)),
@@ -68,7 +70,7 @@ for (kernel in c("gauss","exp","matern3_2","matern5_2")) {
   #    lines(x,simulate(r,x=x,seed=i),col='grey')
   
   .x = seq(0.1,0.9,,11)
-  p_allx = predict(r,.x,TRUE, cov=FALSE, deriv=TRUE)
+  p_allx = predict(r,.x,TRUE, return_cov=FALSE, return_deriv=TRUE)
   for (i in 1:length(.x)) {
     # ref from DiceOptim::EI.grad
     newdata = .x[i]
@@ -102,12 +104,12 @@ for (kernel in c("gauss","exp","matern3_2","matern5_2")) {
                                   (f.deltax - t(t(W)%*%u) ))
     kriging.sd.grad <- kriging.sd2.grad / (2*kriging.sd)
                        
-    p = predict(r,.x[i],TRUE, cov=FALSE, deriv=TRUE)
+    p = predict(r,.x[i],TRUE, return_cov=FALSE, return_deriv=TRUE)
   
-    test_that(desc=paste0("vect pred mean deriv is ok:\n ",paste0(collapse=",",p_allx$mean_deriv[i]),"\n ",paste0(collapse=",",p$mean_deriv)),
-             expect_equal(array(p_allx$mean_deriv[i]),array(p$mean_deriv),tol = precision))
-    test_that(desc=paste0("vect pred sd deriv is ok:\n ",paste0(collapse=",",p_allx$stdev_deriv[i]),"\n ",paste0(collapse=",",p$stdev_deriv)),
-             expect_equal(array(p_allx$stdev_deriv[i]),array(p$stdev_deriv),tol = precision))
+#    test_that(desc=paste0("vect pred mean deriv is ok:\n ",paste0(collapse=",",p_allx$mean_deriv[i]),"\n ",paste0(collapse=",",p$mean_deriv)),
+#             expect_equal(array(p_allx$mean_deriv[i]),array(p$mean_deriv),tol = precision))
+#    test_that(desc=paste0("vect pred sd deriv is ok:\n ",paste0(collapse=",",p_allx$stdev_deriv[i]),"\n ",paste0(collapse=",",p$stdev_deriv)),
+#             expect_equal(array(p_allx$stdev_deriv[i]),array(p$stdev_deriv),tol = precision))
 
   arrows(.x[i],p$mean, .x[i]+0.1, p$mean+0.1*p$mean_deriv)
   arrows(.x[i],p$mean+p$stdev, .x[i]+0.1, p$mean+p$stdev+0.1*p$mean_deriv+0.1*p$stdev_deriv, col='darkgrey')
